# -*- perl -*-

package Bundle::HTML::EP;

$VERSION = '0.01';

1;

__END__

=head1 NAME

Bundle::HTML::EP - A bundle to install the HTML::EP package

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::HTML::EP'>

=head1 CONTENTS

DBI

Data::Dumper

Storable

Bundle::LWP

Net::SMTP

Mail::Internet 1.12

ExtUtils::PerlPP

=head1 DESCRIPTION

This bundle includes all that's needed to run the HTML::EP package with
your WWW server.

=cut
